---
hide:
  - navigation
  - toc
  - footer
---

Download the data [here](stats_as_csv.csv).

Note: This data is updated twice a day. For up-to-date results, consider using the CLI tool instead.

<hr>

{{ read_csv('stats_website/stats_as_csv.csv') }}
